pub enum Persistence {
Buffer,
Sync,
BufferThenSync,
}Expand description
The persistence mode to use on the database.
Variants
Buffer
Buffer the changes but don’t wait for them to be synced to disk.
This can lead to corruption if there is a crash.
Sync
Sync all changes to disk.
This prevents corruption but can be a bit slower.
BufferThenSync
Buffer changes while syncing but then switch to syncing all changes to disk once synced.
This is a compromise between Self::Buffer and Self::Sync.